@@ -1,3 +1,12 @@
+from __future__ import absolute_import
+
+from six import string_types
+
+
+def cmp(a, b):
+    return (a > b) - (a < b)
+
+
 class Bit(object):
     """
     Represents a single Bit.
@@ -122,6 +131,21 @@ class BitHandler(object):
             return False
         return self._value == other._value
 
+    def __lt__(self, other):
+        return int(self._value) < other
+
+    def __le__(self, other):
+        return int(self._value) <= other
+
+    def __gt__(self, other):
+        return int(self._value) > other
+
+    def __ge__(self, other):
+        return int(self._value) >= other
+
+    def __cmp__(self, other):
+        return cmp(self._value, other)
+
     def __repr__(self):
         return '<%s: %s>' % (self.__class__.__name__, ', '.join('%s=%s' % (k, self.get_bit(n).is_set) for n, k in enumerate(self._keys)),)
 
@@ -214,8 +238,30 @@ class BitHandler(object):
             yield (k, getattr(self, k).is_set)
 
     def get_label(self, flag):
-        if isinstance(flag, basestring):
+        if isinstance(flag, string_types):
             flag = self._keys.index(flag)
         if isinstance(flag, Bit):
             flag = flag.number
         return self._labels[flag]
+
+
+import django
+
+if django.VERSION[:2] >= (1, 8):
+    from django.core.exceptions import ImproperlyConfigured
+
+    # We need to register adapters in Django 1.8 in order to prevent
+    # "ProgrammingError: can't adapt type"
+    try:
+        from django.db.backends.sqlite3.base import Database
+        Database.register_adapter(Bit, lambda x: int(x))
+        Database.register_adapter(BitHandler, lambda x: int(x))
+    except ImproperlyConfigured:
+        pass
+
+    try:
+        from django.db.backends.postgresql_psycopg2.base import Database
+        Database.extensions.register_adapter(Bit, lambda x: Database.extensions.AsIs(int(x)))
+        Database.extensions.register_adapter(BitHandler, lambda x: Database.extensions.AsIs(int(x)))
+    except ImproperlyConfigured:
+        pass
